---
menutitle: "FAQ"
title: "Frequently asked questions"
date: 2020-08-02T21:26:25+02:00
draft: false
weight: 200
---
This is a compilation of frequently asked questions and their answers. In some cases, the answers have not yet been formulated. In these cases, please ask in the [#helpdesk:kit.edu](https://matrix.to/#/#helpdesk:kit.edu) room.

- [Message cannot be decrypted](#unable-to-decrypt)
- [I do not have a recovery key](#no-recovery-key)
- [How do I change the security phrase for my key backup?](#change-securityphrase)
- [How can I reset the key backup if I have lost my security phrase AND my security key?](#reset-securityphrase)
- [What should I do if video or audio in a video conference does not work on a Mac or MacBook?](#apple-no-video)
- [I cannot invite a fellow student or researcher](#unable-to-invite)
- [The connection to the server has been lost](#no-connection)
- [My client says „missing translation: ...“ everywhere](#missing-translations)
- [Is our server on your federation blocklist?](#blocklist)
- [I do not see any messages from a certain person in a room](#blocked-user)
- [How can I use matrix? / I can't find instructions on how I or others can use matrix.](#how-to-login)
- [I have logged on to a second device and cannot read my messages](#second-device-no-messages)
- [I have study/research colleagues who also want to use this. Can they also register with KIT matrix? / How can I collaborate with externals in matrix?](#login-for-external-users)
- [How do you tell people a room address?](#share-room)
- [How can I as an admin delete many messages at once?](#delete-multiple-messages)
- [Sometimes I see a bold marked room and click on it, but yet I don't have the time to immediately edit the content and any consequences for me. How can I mark the room as "unread" again?](#mark-room-as-unread)
- [Can I write LaTeX?](#latex)
- [Is there such a thing as threads (as in Mattermost/Slack) in matrix?](#threads)
- [I have 2 KIT accounts, can I have messages forwarded from one to the other?](#forward-account)
- [Can I hold video conferences in matrix?](#videoconf-in-matrix)
- [Is it possible to send files via matrix? / What is the maximum file size that can be sent via matrix?](#file-upload)
- [Can I install a matrix app on my phone without getting notifications?](#app-without-notifications)
- [Is it possible to be notified when there are new messages in matrix without opening an app/website?](#notifications-via-email)
- [Can I manage multiple matrix accounts with Element (multi-account client)?](#multiple-accounts-element)
- [How can I operate a (chat)bot in Matrix?](#bot)

***
# Troubleshooting

#### Message cannot be decrypted {#unable-to-decrypt}
- **Does this occur with all messages in a room (or all messages in all private rooms)?**
  The login where the messages are not visible has not been verified. Please either
    - Enter security key or security passphrase (these were set at your first login), or
    - Verify this login interactively (you compare emoji between the first and the second login). More info about this can be found [here](/en/first-steps).
    - Check if the setting "Encrypt to verified sessions only from this session" is set. The setting can be set for each login/device or for each room. The setting issues, that unverified counterparts cannot read messages sent from this device / in this room. Security-conscious users without Matrix experience may activate the setting without understanding its implications. The setting makes sense when writing with personally known **and verified** counterparts and can increase security there. However, if you want to exchange messages with not yet verified strangers (especially in groups), you should set this setting with caution and only per room (e.g. for rooms with sensitive content). Security-conscious users should trust and pay more attention to the display of green/red shields next to names and red schields next to messages.
- **Does this only occur with messages in a certain time period?**
  Most likely, no device was logged in with your account during that time period. To use matrix safely, it is *not* necessary to log out of sessions (e.g. before closing the browser), so it is recommended to just stay logged in on devices you want to use again and close the website/app directly if desired. This way, messages can be correctly encrypted and delivered even when no device is switched on.
  If you were always logged in with at least one device, your browser settings (if you use Element in the browser) could also cause the problem. Make sure that the browser does not delete local data, cookies or similar on its own.
- **Does this occur sporadically / only once?**
  You can first check if there are logins for your account that are not verified (this can usually be found in security settings of the respective app or website), and ask the sender of the message to do the same. Sometimes this error is unrecoverable, in which case it's best to ask the sender to resend the message.
***

#### I do not have a recovery key {#no-recovery-key}
Please check whether you have set up the secure key backup. See [Key Backup](/en/settings/#key-backup).
***

#### How do I change the security phrase for my key backup? {#change-securityphrase}
- For all matrix sessions except one, which is still accessible, export the room keys `Settings` -> `Security & Privacy` -> `Encryption`. Finally, log out by clicking on the user name in the upper left corner and log out. If you are asked whether you want the encrypted messages, click on 'I don't want my encrypted messages', because these keys have already been exported.
- Under `Settings`-> `Security & Privacy` -> `Secure Backup` first click the button `Delete Backup`, then the button `Reset`, possibly a deletion of the cache under `Settings`-> `Help & About` is necessary, possibly also a logout and a new logon with a subsequent new attempt. If all this does not work, continue in the next point. The action was successful, if only the green Setup button is displayed.
- For all previously exported key backups, perform the manual import procedure.
- Set up a new key backup. See [Key Backup](/en/settings/#key-backup).
***

#### How can I reset the key backup if I have lost my security phrase AND my security key? {#reset-securityphrase}
Please do the following:
  1. In a matrix session (that is, client/device/browser), where you can still read the previous encrypted conversations, export the room keys. To do this, go to `Settings`-> `Security` -> `Encryption` and click on Export E2E room keys. If there is no more access to any matrix session where previous encrypted messages are readable, skip this step.
  2. In the one matrix session where you just exported the room keys manually in step 1, go to `Settings` -> `Security` -> `Encryption`, tick all other sessions at the end of the line and click on the red bordered button "log off x selected devices" below the list. The topmost one in bold is the current session, do not tick this one, i.e. do not delete it.
  3. If necessary, log out and then log in again, ignoring any requests.
  4. Under `Settings`-> `Security` -> `Secure Backup` look if there is a green button `Setup` and no red buttons. Or if there are still red buttons, first click the button `Delete Backup`, then the button `Reset`. It may be necessary to clear the cache (red button under `Settings`-> `Help & About`), possibly also to log out and log in again. 
  5. Afterwards press the red button `Reset` under `Settings`-> `Security` -> `Cross-signing`. The action was successful, if for 'Secure Backup' and 'Cross Signing' only the green 'Set Up' button is displayed. 
  6. Now import the previously exported key backups manually. To do this, go to `Settings`-> `Security` -> `Encryption` and click on Import E2E room keys.
  7. Set up new key backup and cross signing with the two green buttons. See [Key Backup](/en/settings/#key-backup). You can print out the security key, for example, and keep it safe.
***

#### What should I do if video or audio in a video conference does not work on a Mac or MacBook? {#apple-no-video}
Often Element does not have the rights to access the webcam and microphone. These can be assigned in the system settings under Security and Privacy.
***

#### I cannot invite a fellow student or researcher {#unable-to-invite}
- First check the spelling (was the acronym or name really entered correctly?).
- It is not possible to invite or search for users with their e-mail address. It is best to either search for the acronym (if known), or "on the off chance" search for the person's first and/or last name (this only works if the person has chosen them as the display name).
- Users can only be invited if they have registered at least once. If the acronym / matrix ID can not be found, this user has never logged into matrix.
***

#### The connection to the server has been lost {#no-connection}
1. Does your device have access to the Internet? Make sure that it is not a missing mobile connection, unplugged internet cable, or similar.
2. For maintenance of the system, the matrix server is sometimes restarted briefly, in this case the service is available again after a few minutes.
3. Longer outages are possible for technical or security reasons, possibly the use of the service was also limited to the KIT network. In this case, please use the KIT VPN.
***

#### My client says „missing translation: ...“ everywhere {#missing-translations}
This phenomenon is often related to unfinished updates of the matrix client. Reload the cache: Go to the "Help and About" category in the Element settings and scroll all the way down: "Clear cache and reload" should fix the display problem.
***

#### Is our server on your federation blocklist? {#blocklist}
Currently there is no server on our Federation blocklist. This cannot be the reason for any Federation problems.
***

#### I do not see any messages from a certain person in a room {#blocked-user}
A common reason for this is that you have misclicked and the person you no longer see messages from, even though you are told there should be something there, has been blocked by you. To do this, open your security settings and scroll way down. Check if there are entries in the "Blocked users" category that don't belong there. Remove them if necessary.
***

# Login
#### How can I use matrix? / I can't find instructions on how I or others can use matrix. {#how-to-login}
For instructions, see these help pages for Element [for use in the browser](/en/first-steps"), on [Android](/en/clients/android), and on [iOS](/en/clients/ios).

For other clients, instructions can be found on the internet as well.
***

#### I have logged on to a second device and cannot read my messages {#second-device-no-messages}
Encrypted messages are only visible after the new login has been verified. For this you can either
- Enter security key or security passphrase on the new device (these were set during the first login), or
- Verify the second login interactively (you compare emoji between the first and second login).

More info about this can be found [here](/en/first-steps).
***

#### I have study/research colleagues who also want to use this. Can they also register with KIT matrix? / How can I collaborate with externals in matrix? {#login-for-external-users}
KIT's matrix service is limited to members of KIT (that is, everyone who can log in to the KIT Shibboleth). However, in matrix it does not matter with which operator one is registered. So external users can find out if their institution is already running matrix and
- if yes, register there and be invited to chat rooms or direct messages as usual.
- if not, create an account at any public matrix server (lists are available e.g. [here](https://joinmatrix.org/servers/)), and be invited to chat rooms or direct messages as usual.
***

# Using matrix
#### How do you tell people a room address? {#share-room}
With the "https://matrix.to/..." link, which you can see under the i-symbol for the room properties and another click on "share room".
***

#### How can I as an admin delete many messages at once? {#delete-multiple-messages}
Please contact us in [#helpdesk:kit.edu](https://matrix.to/#/#helpdesk:kit.edu).
***

#### Sometimes I see a bold marked room and click on it, but yet I don't have the time to immediately edit the content and any consequences for me. How can I mark the room as "unread" again? {#mark-room-as-unread}
Unfortunately, this is not possible in Element. As an interim solution, you can mark the room as a favorite and note to yourself that your own favorites should be looked at again.
***


# "Can I..?" (Features etc.)
#### Can I write LaTeX? {#latex}
Yes! But it is an experimental feature, you can turn it on in `Settings` -> `Labs` -> `Messaging` and then write latex between dollar signs: `$\LaTeX$`.
***

#### Is there such a thing as threads (as in Mattermost/Slack) in matrix? {#threads}
Yes, matrix supports the use of threads. However, these are still quite new and not optimally usable in all clients.
***

#### I have 2 KIT accounts, can I have messages forwarded from one to the other? {#forward-account}
Not without further ado, no. Technically it is doable, but only with some prior knowledge. If you are interested, feel free to contact us in the matrix room [#about-matrix:kit.edu](https://matrix.to/#/#about-matrix:kit.edu).
***

#### Can I hold video conferences in matrix? {#videoconf-in-matrix}
At the moment, only 1:1 calls (also with video) are supported. In a few months, group calls with a generally unlimited number of participants will also be possible. It remains to be tested how many camera images can be used simultaneously then.

A very preliminary version is already available, you can switch it on in `Settings` -> `Labs`.
***

#### Is it possible to send files via matrix? / What is the maximum file size that can be sent via matrix? {#file-upload}
In KIT's matrix service, currently uploading of files up to 250 megabytes is allowed. For users at other operators who have set a lower limit, it might not be possible to download files larger than their limit. Generally, the maximum size for most operators is 200 megabytes.
***

#### Can I install a matrix app on my phone without getting notifications? {#app-without-notifications}
Yes, most apps allow you to turn off notifications completely. This is possible in the settings of the respective app.

You can also selectively turn off notifications for particularly large/busy/unimportant chat rooms, this is usually done by long-pressing on the desired room in the room list and then making the notification settings at the bottom or top of the screen (in Element, 4 possible notification levels appear at the bottom of the screen).
***

#### Is it possible to be notified when there are new messages in matrix without opening an app/website? {#notifications-via-email}
Yes, it is possible to receive emails when there are new messages or room invitations in your matrix account. More info can be found [here](/en/settings).
***

#### Can I manage multiple matrix accounts with Element (multi-account client)? {#multiple-accounts-element}
An Element window can currently manage only one matrix account. However, you can, for example, use different clients for the different accounts, including [SchildiChat](https://schildi.chat/), which is very similar to Element. In addition, there are clients, such as [FluffyChat](https://fluffychat.im/), which can manage multiple accounts in just one app (or browser tab).

It is also possible to start several Element windows with different matrix accounts, even in the autostart of the computer. To do this, modify the program call to open a specific profile:
```
element-desktop --profile PROFILENAME
```
This way several starters can be placed in the autostart, which then have different profile names, e.g. --profile KIT and --profile PRIVATE. Unfortunately both open windows have the same looking icons in the indicator applet. But there will be a solution for this soon...
***

#### How can I operate a (chat)bot in Matrix? {#bot}
Operating a bot in Matrix is possible.
There are already many ready-made [bots and libraries](https://matrix.org/bots/) available for this purpose.
A separate account is required for a bot.
At KIT, a  [KIT service account](https://www.scc.kit.edu/en/services/8637.php) can be used for this purpose.
To allow the bot to connect, the access token for the KIT service account is required, which can be retrieved by [reading it from the Element client](https://t2bot.io/docs/access_tokens/).
***
